module.exports = function(grunt) {

    grunt.initConfig({
        pkg: grunt.file.readJSON('package.json'),

        concat: {
            options: {
                stripBanners: true,

                banner: '/**\n'  +
                    ' * <%= pkg.name %> <%= pkg.version %>\n' +
                    ' * <%= pkg.author.url %>\n *\n' +
                    ' * Copyright <%= grunt.template.today("yyyy") %>, <%= pkg.author %>\n' +
                    ' * All rights reserved.\n' +
                    ' */\n\n'
            },
            dist: {
                src: [
                    'js/game/*.js' // All files in the game folder
                ],
                dest: 'js/game.js'
            }
        },
        zipup: {
            custom_filename: {
                appName: '<%= pkg.name %>',
                version: '<%= pkg.version %>',
                datetime: grunt.template.today('yyyymmdd'),
                template: 'ld31-tiny-adventure.zip',

                // custom data to use in the template
                purpose: 'postcomp',
                files: [
                    { src: 'css/**', expand: true },
                    { src: 'fonts/**', expand: true },
                    { src: 'img/**', expand: true },
                    { src: 'js/**', expand: true },
                    { src: 'snd/**', expand: true },
                    { src: '*.js', expand: true },
                    { src: '*.png', expand: true },
                    { src: '*.html', expand: true },
                    { src: '*.txt', expand: true },
                    { src: '*.json', expand: true }

                ]

            }
        },
        watch: {
            scripts: {
                files: '**/*.js',
                tasks: ['default'],
                options: {
                    debounceDelay: 250,
                },
            },
        },
    });

    // Tell grunt to use the concat plugin.
    grunt.loadNpmTasks('grunt-contrib-concat');
    // Tell grunt to use the watch plugin
    grunt.loadNpmTasks('grunt-contrib-watch');

    // Zip up the source code.
    grunt.loadNpmTasks('grunt-zipup');

    // Default task for the command line.
    grunt.registerTask('default', ['concat']);

};
